__all__ = ['attachment_type']


class attachment_type:
    PNG = 'image/png'
    JPEG = 'image/jpeg'
    TXT = 'text/plain'
    JSON = 'application/json'
    YAML = 'application/json'
    PDF = 'application/pdf'
    PCAP = 'application/vnd.tcpdump.pcap'